# Generated by Django 2.2.4 on 2019-08-16 16:04

import django.contrib.postgres.fields.jsonb
from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('matialvarezs_charge_controller', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='LocalDataBackup',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('identity', models.CharField(max_length=2048, unique=True)),
                ('created', models.DateTimeField(default=django.utils.timezone.now)),
                ('last_update', models.DateTimeField(default=django.utils.timezone.now)),
                ('data', django.contrib.postgres.fields.jsonb.JSONField()),
                ('send_to_server', models.BooleanField(default=True)),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
