# Generated by Django 2.2.4 on 2019-08-16 04:32

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='RegistersData',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('identity', models.CharField(max_length=2048, unique=True)),
                ('created', models.DateTimeField(default=django.utils.timezone.now)),
                ('last_update', models.DateTimeField(default=django.utils.timezone.now)),
                ('address', models.IntegerField(default=0)),
                ('code', models.CharField(default='', max_length=512)),
                ('count', models.IntegerField(default=1)),
                ('times', models.IntegerField(default=1)),
                ('unit', models.IntegerField(default=1)),
                ('function_code', models.IntegerField(default=0)),
                ('bits', models.BooleanField(default=False)),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
